import {Component, OnInit} from '@angular/core';
import {environment} from '../../../../environments/environment';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {IconService} from '../../../services/icon.service';
import {NzMessageService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {CommonsService} from '../../../services/commons.service';
import {AgentService} from '../../../services/agent.service';
import {DiscountService} from '../../../services/discount.service';
import {CouponService} from '../../../services/coupon.service';
import {ClipboardService} from 'ngx-clipboard';
import {AuditService} from '../../../services/audit.service';

@Component({
    selector: 'app-agent-list',
    templateUrl: './agent-list.component.html',
    styleUrls: ['./agent-list.component.scss']
})
export class AgentListComponent implements OnInit {

    WEB_SERVE_URL = environment.imageUrl;
    inviteUrl = environment.inviteUrl;
    searchForm: FormGroup; // 搜索框
    validateForm: FormGroup; // 搜索框
    validateFormDistribute: FormGroup; // 搜索框
    validateFormDiscountPackage:FormGroup;//搜索框

    requestData = []; // 列表数据
    discountList = []; // 列表数据
    couponList = []; // 列表数据
    distributeList = []; // 列表数据
    discountPackageList=[];//优惠券包列表
    distributeCouponsList=[];//优惠券包分发列表
    packageAgentRecordList=[];//优惠券包分发记录列表
    total: number; // 页码
    pageNum = 1; // 页码
    pageSize = 10; // 条码
    loading = true;
    isVisible = false;
    isVisibleDiscountPackage = false;
    isVisibleDiscount = false;
    isVisibleDistribute = false;
    isVisibleDistributeCoupons=false;
    isVisibleDistributeCouponsList=false;
    isVisibleAgentRecordList=false;
    isVisibleList = false;
    id: number;
    isSpinning = false;
    isSpinningDistribute = false;
    isSpinningDistributeCoupons=false;
    requestDataDiscount = []; // 列表数据
    totalDiscount: number; // 页码
    pageNumDiscount = 1; // 页码
    pageSizeDiscount = 10; // 条码
    loadingDiscount = true;
    agentId: number;
    requestDataList = []; // 列表数据
    totalList: number; // 页码
    pageNumList = 1; // 页码
    pageSizeList = 10; // 条码
    loadingList = true;
    loadingCouponsList=false;
    isOkLoading = false;
    isOkCouponsLoading=false;
    isVisibleShow = false;
    isVisiblePercent = false;
    percent = 0;
    dataSet;
    type: number;
    processRateInterval;
    loadingObject = {
        title: '加载中...',
        status: false,
    };
    constructor(
        private form: FormBuilder,
        private agent: AgentService,
        private audit: AuditService,
        private discount: DiscountService,
        private coupon: CouponService,
        private message: NzMessageService,
        private router: Router,
        private clipboardService: ClipboardService,
        private common: CommonsService
    ) {
    }

    ngOnInit(): void {
        this.init();
    }

    public init(): void {
        this.searchForm = this.form.group({
            agentName: [null],
            agentPhone: [null],
            status: [null],
            type: [null],
        });

        this.validateForm = this.form.group({
            discountId: [null, [Validators.required]],
            stockCount: [null, [Validators.required]],
        });
        this.validateFormDistribute = this.form.group({
            couponId: [null, [Validators.required]],
            type: [null, [Validators.required]],
            stockCount: [null, [Validators.required]],
        });

        this.validateFormDiscountPackage=this.form.group({
            discountPackageId:[null,[Validators.required]],
            num:[null, [Validators.required,Validators.min(1)]]
        })

        this.getRequest(true, this.searchForm.value);

        this.coupon.getCouponListByAll({} , data => {
            if (data['return_code'] === '000000') {
                this.couponList = data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 查询列表
    public getRequest(reset: boolean = false, whereObject: object) {

        this.loading = false;
        if (reset) {
            this.pageNum = 1;
        }
        whereObject['pageNum'] = this.pageNum;
        whereObject['pageSize'] = this.pageSize;
        this.agent.getListAgent(whereObject, data => {
            if (data['return_code'] === '000000') {
                this.requestData = data['return_data'].list;
                this.total = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 重置
    public resetForm(): void {
        this.searchForm.reset();
    }

    public getForbiddenUser(id, status: any): void {
        const message = (status === 1 ? '是否禁用当前代理商' : '是否启用当前代理商');

        this.common.showConfirm(message, data => {
            if (data) {
                this.agent.editStatus(id, dataUser => {
                    this.getRequest(false, this.searchForm.value);
                });
            }
        });
    }

    // 修改
    public getEdit(id: number): void {
        this.router.navigate(['/admin/agent/agent-edit'], {
            queryParams: {
                agentId: id
            }
        }).then(r => console.log(r));
    }

    // 查看详情
    public getDetail(id: number): void {
        this.router.navigate(['/admin/company/company-detail'], {
            queryParams: {
                companyId: id
            }
        }).then(r => console.log(r));
    }

    // 绑定优惠券
    public getDiscount(id: number): void {
        this.id = id;
        const whereObject = {};
        whereObject['pageNum'] = 1;
        whereObject['pageSize'] = 10000;
        this.discount.getDiscountList(whereObject, data => {
            if (data['return_code'] === '000000') {
                this.discountList = data['return_data'].list;
            } else {
                this.message.error(data['return_msg']);
            }
        });
        this.isVisible = true;
    }

    handleOk(): void {
        // tslint:disable-next-line:forin
        for (const i in this.validateForm.controls) {
            this.validateForm.controls[i].markAsDirty();
            this.validateForm.controls[i].updateValueAndValidity();
            if (this.validateForm.controls[i].errors != null) {
                this.message.error('必填项不能为空');
                return;
            }
        }
        // this.isSpinning = true;
        this.validateForm.value['agentId'] = this.id;
        this.agent.insertDiscountAgent(this.validateForm.value , data => {
            if (data['return_code'] === '000000') {
                this.message.success('生成中，请耐心等待！');
                this.isVisible = false;
            } else {
                this.message.error(data['return_msg']);
            }
            this.isSpinning = false;
        });
    }

    handleCancel(): void {
        this.isVisible = false;
    }

    public getDiscountList(id: number): void {
        this.id = id;
        this.isVisibleDiscount = true;
        this.getRequestDiscount(true);
    }


    public getDistributionList(id: number): void {
        this.id = id;
        this.isVisibleList = true;
        this.getRequestList(true);
    }

    handleCancelList() {
        this.isVisibleList = false;
    }

    handleCancelDiscount() {
        this.isVisibleDiscount = false;
    }
    handleCancelDistribute() {
        this.isVisibleDistribute = false;
    }
    // 查询列表
    public getRequestDiscount(reset: boolean = false) {
        const whereObject = {};
        this.loadingDiscount = true;
        if (reset) {
            this.pageNumDiscount = 1;
        }
        whereObject['pageNum'] = this.pageNumDiscount;
        whereObject['pageSize'] = this.pageSizeDiscount;
        whereObject['agentId'] = this.id;
        this.agent.getDiscountAgentList(whereObject, data => {
            this.loadingDiscount = false;
            if (data['return_code'] === '000000') {
                this.requestDataDiscount = data['return_data'].list;
                this.totalDiscount = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 提交分发审批
    public addApprove(): void {

        // tslint:disable-next-line:forin
        for (const i in this.validateFormDistribute.controls) {
            this.validateFormDistribute.controls[i].markAsDirty();
            this.validateFormDistribute.controls[i].updateValueAndValidity();
            if (this.validateFormDistribute.controls[i].errors != null) {
                this.message.error('必填项不能为空');
                return;
            }
        }
        this.isOkLoading = true;

        console.log(this.couponList);
        console.log(this.distributeList);

        this.validateFormDistribute.value['agentName'] = this.requestData.find(data => data.id == this.agentId).agentName;
        this.validateFormDistribute.value['couponName'] = this.distributeList.find(data => data.id == this.validateFormDistribute.value['couponId']).couponName;
        this.validateFormDistribute.value['agentId'] = this.agentId;

        const whereObject = {
            objectType: 3,
            approveObject: this.validateFormDistribute.value,
        };

        this.audit.addApprove(whereObject , data => {
            if (data['return_code'] === '000000') {
                this.validateFormDistribute.reset();
                this.message.success('提交成功');
                this.isVisibleDistribute = false;
            } else {
                this.message.error(data['return_msg']);
            }
            this.isOkLoading = false;
        });

    }

    // 分发卡券
    public getDistribution(id: number): void {
        this.isSpinningDistribute = true;
        this.agentId = id;
        const whereObject = {};
        whereObject['pageNum'] = 1;
        whereObject['pageSize'] = 10000;
        this.coupon.getCouponList(whereObject, data => {
            if (data['return_code'] === '000000') {
                this.distributeList = data['return_data'].list;
            } else {
                this.message.error(data['return_msg']);
            }
            this.isSpinningDistribute = false;
        });
        this.isVisibleDistribute = true;
    }

    // 查询f分发列表
    public getRequestList(reset: boolean = false) {
        const whereObject = {};
        this.loadingList = true;
        if (reset) {
            this.pageNumList = 1;
        }
        whereObject['pageNum'] = this.pageNumList;
        whereObject['pageSize'] = this.pageSizeList;
        whereObject['agentId'] = this.id;
        this.agent.getCouponByAgent(whereObject, data => {
            this.loadingList = false;
            if (data['return_code'] === '000000') {
                this.requestDataList = data['return_data'].list;
                this.totalList = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 提交分发
    public handleOkDistribute(): void {
        // tslint:disable-next-line:forin
        for (const i in this.validateFormDistribute.controls) {
            this.validateFormDistribute.controls[i].markAsDirty();
            this.validateFormDistribute.controls[i].updateValueAndValidity();
            if (this.validateFormDistribute.controls[i].errors != null) {
                this.message.error('必填项不能为空');
                return;
            }
        }
        this.isOkLoading = true;
        this.validateFormDistribute.value['agentId'] = this.agentId;
        this.agent.assignCouponAgent(this.validateFormDistribute.value , data => {
            if (data['return_code'] === '000000') {
                this.validateFormDistribute.reset();
                this.message.success('分发成功');
                this.isVisibleDistribute = false;
                this.isOkLoading = false;
            } else {
                this.message.error(data['return_msg']);
            }
            this.isSpinning = false;
        });
    }

    // 获取优惠券包列表
    public getDistributeCoupons(id: number , type: number): void{
        this.validateFormDiscountPackage.reset();

        this.isSpinningDistributeCoupons = true;
        this.agentId = id;
        const whereObject = {};
        whereObject['pageNum'] = 1;
        whereObject['pageSize'] = 10000;
        whereObject['status']= 1;
        this.agent.getDiscountPackageList(whereObject,(data)=>{
            if (data['return_code'] === '000000') {
                this.discountPackageList = data['return_data'].list;
            } else {
                this.message.error(data['return_msg']);
            }
            this.isSpinningDistributeCoupons=false;
        })

        if (type == 1) {
            this.isVisibleDistributeCoupons=true;
        } else {
            this.isVisibleDiscountPackage = true;
        }

    }


   
    //分发优惠券包 确定
    public addDisCoupon(type: number): void{
        for (const i in this.validateFormDiscountPackage.controls) {
            this.validateFormDiscountPackage.controls[i].markAsDirty();
            this.validateFormDiscountPackage.controls[i].updateValueAndValidity();
            if (this.validateFormDiscountPackage.controls[i].errors != null) {
                this.message.error('必填项不能为空');
                return;
            }
        }
        this.isOkCouponsLoading=true;
        this.validateFormDiscountPackage.value['agentId'] = this.agentId;

        if (type == 1) {

            this.agent.distribute(this.validateFormDiscountPackage.value,(data)=>{
                this.isOkCouponsLoading=false;
                if (data['return_code'] === '000000') {
                    this.validateFormDiscountPackage.reset();
                    this.message.success('分发成功');
                    this.isVisibleDistributeCoupons = false;
                } else {
                    this.message.error(data['return_msg']);
                }

            })
        } else {
            this.percent = 0;
            this.validateFormDiscountPackage.value['serialNumber'] = new Date().getTime();
            this.processRate(this.validateFormDiscountPackage.value['serialNumber']);
            this.isVisiblePercent = true;
            this.agent.generateDiscountPackageAgentCode(this.validateFormDiscountPackage.value,(data)=>{
                this.isOkCouponsLoading=false;
                this.loadingObject.status = false;
                if (data['return_code'] === '000000') {
                    this.validateFormDiscountPackage.reset();
                    this.isVisibleDiscountPackage = false;
                } else {
                    this.message.error(data['return_msg']);
                }

            })
        }

        
    }


    // 优惠券包分发列表
    public getDistributeCouponsList(id:number , type: number):void{
        this.agentId = id;
        this.isVisibleDistributeCouponsList=true;
        this.loadingCouponsList=true;
        this.distributeCouponsList=[];
        this.type = type;
        this.agent.getDiscountPackageAgentRelList(this.agentId, type ,(data)=>{
            this.loadingCouponsList=false;
            if (data['return_code'] === '000000') {
                this.distributeCouponsList = data['return_data'];
                
            } else {
                this.message.error(data['return_msg']);
            }
        })

    }

    // 获取优惠券包代理商分发记录列表
    public getRecordList(discountPackageId:number):void{

        const params={};
        params["discountPackageId"]=discountPackageId;
        params["agentId"]=this.agentId;
        params["type"]= this.type;

        this.isVisibleAgentRecordList=true;
        this.packageAgentRecordList=[];
        this.agent.getDiscountPackageAgentRecord(params,(data)=>{
            if (data['return_code'] === '000000') {
                this.packageAgentRecordList = data['return_data'];
                
            } else {
                this.message.error(data['return_msg']);
            }
        })
    }


    public getList(id: number): void {
        const whereObject = {};
        whereObject['pageNum'] = 1;
        whereObject['pageSize'] = 10000;
        whereObject['couponAgentId'] = id;
        this.isVisibleShow = true;
        this.agent.getRecordByCouponAgentId(whereObject , data => {
            if (data['return_code'] === '000000') {
                this.dataSet = data['return_data'].list;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    handleCancelListShow() {
        this.isVisibleShow = false;
    }

    public generateAgentQrCode(id: number): void {
        this.agent.generateRechargeAgentQrCode(id, data => {
            if (data['return_code'] === '000000') {
                window.location.href = this.WEB_SERVE_URL + data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }


    copyReceiveDiscountLink(id: number) {
        this.agent.getReceiveLink(id, data => {
           if (data['return_code']) {
               this.clipboardService.copy(data['return_data']);
               this.message.success('复制成功');
           } else {
               this.message.error('复制失败');
           }
        });
    }

    // 获取导出百分比
    processRate(key: string) {
        this.processRateInterval = setInterval(() => this.common.getRedisValueByType(key, data => {
            this.percent = data['return_data'];
            if (this.percent === 100) {
                clearTimeout(this.processRateInterval);
                this.message.success('生成成功！');
                this.loadingObject.status = false;
                this.isVisiblePercent = false;
            }
        }), 100);


    }

}

