import { Component, OnInit } from '@angular/core';
import {environment} from '../../../../environments/environment';
import {CommonsService} from '../../../services/commons.service';
import {GoodsService} from '../../../services/goods/goods.service';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {NzModalService, NzNotificationService} from 'ng-zorro-antd';

@Component({
  selector: 'app-freight',
  templateUrl: './freight.component.html',
  styleUrls: ['./freight.component.scss']
})
export class FreightComponent implements OnInit {

    // 搜索框
    searchForm: FormGroup;
    // 表单
    validateForm: FormGroup;
    url = environment;
    // 列表数据
    requestData = [];
    // 总数
    total: number;
    // 页码
    pageNum = 1;
    // 条码
    pageSize = 10;
    // 等待
    loading = false;
    // 是否修改
    editFlag = false;
    // 编辑等待
    isSpinningEdit = false;
    // 弹出框编辑
    isVisible = false;
    id;
    regionalData = [];
    constructor(
        private form: FormBuilder,
        private notification: NzNotificationService,
        private commonsService: CommonsService,
        private modalService: NzModalService,
        private goods: GoodsService
    ) {
    }

    // 输入框内容
    formatterPercent = (value: number): string => `${value == null ? 0 : value} ¥`;
    parserPercent = (value: string): string => value.replace(' ¥', '');


    ngOnInit(): void {

        // 初始化搜索表单
        this.searchForm = this.form.group({
            regionName: [null],
            regionId: [null],
        });
        // 初始化商品表单
        this.validateForm = this.form.group({
            regionId: [null, [Validators.required]],
            freePostPrice: [null, [Validators.required]],
            freightPrice: [null, [Validators.required]],
        });
        this.getRequest(true, this.searchForm.value);
        this.commonsService.getRegional(data => {
            if (data['return_code'] === '000000') {
                this.regionalData = data['return_data'];
            }
        });

    }

    // 查询列表
    public getRequest(reset: boolean = false, whereObject: object) {

        this.loading = true;
        if (reset) {
            this.pageNum = 1;
        }
        whereObject['pageNum'] = this.pageNum;
        whereObject['pageSize'] = this.pageSize;
        this.goods.getListRegionFreight(whereObject, data => {
            this.loading = false;
            if (data['return_code'] === '000000') {
                this.requestData = data['return_data'].list;
                this.total = data['return_data'].total;
            } else {
                this.notification.error('失败', data['return_msg']);
            }
        });
    }

    // 编辑产品
    public getEdit(id?: number): void {
        this.isVisible = true;
        this.id = id;
        if (id != null) {
            this.editFlag = true;
            this.findGoodsDetailById(id);
        }
    }


    // 查询商品详情
    public findGoodsDetailById(id: number): void {
        this.goods.findRegionFreightById(id , data => {
            if (data['return_code'] === '000000') {
                data['return_data']['regionId'] = Number(data['return_data']['regionId']);
                this.validateForm.patchValue(data['return_data']);
            }
        });
    }

    // 确认提交
    public handleOkEdit() {
        for (const i in this.validateForm.controls) {
            this.validateForm.controls[i].markAsDirty();
            this.validateForm.controls[i].updateValueAndValidity();
            if (this.validateForm.controls[i].errors != null) {
                return;
            }
        }


        if (this.editFlag) {
            this.validateForm.value.id = this.id;
            this.isSpinningEdit = true;
            this.goods.updateRegionFreight(this.validateForm.value, data => {
                this.isSpinningEdit = false;
                if (data['return_code'] === '000000') {
                    this.notification.success('成功', '修改成功!');
                    this.isVisible = false;
                    this.getRequest(true, this.searchForm.value);
                } else {
                    this.notification.error('失败', data['return_msg']);
                }
            });
        } else {
            this.goods.insertRegionFreight(this.validateForm.value, data => {
                this.isSpinningEdit = false;
                if (data['return_code'] === '000000') {
                    this.notification.success('成功', '添加成功!');
                    this.isVisible = false;
                    this.getRequest(true, this.searchForm.value);
                } else {
                    this.notification.error('失败', data['return_msg']);
                }
            });
        }
    }
    // 删除商品
    public deleteFreight(id): void {
        this.modalService.confirm({
            nzTitle: '确定删除',
            nzOkText: '是',
            nzOnOk: () => {
                this.goods.deleteRegionFreight(id, data => {
                    if (data['return_code'] === '000000') {
                        this.notification.success('成功', `删除成功！`);
                        this.getRequest(true, this.searchForm.value);
                    } else {
                        this.notification.error('失败', data['return_msg']);
                    }
                });
            },
            nzCancelText: '否',
        });
    }


}
