import {Component, OnInit} from '@angular/core';
import {environment} from '../../../../environments/environment';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {IconService} from '../../../services/icon.service';
import {NzMessageService, NzModalService, NzUploadFile} from 'ng-zorro-antd';
import {ConfigService} from '../../../services/config.service';
import {Router} from '@angular/router';
import {CommonsService} from "../../../services/commons.service";

function getBase64(file: File): Promise<string | ArrayBuffer | null> {
    return new Promise((resolve, reject) => {
        const reader = new FileReader();
        reader.readAsDataURL(file);
        reader.onload = () => resolve(reader.result);
        reader.onerror = error => reject(error);
    });
}

@Component({
    selector: 'app-goods-type',
    templateUrl: './goods-type.component.html',
    styleUrls: ['./goods-type.component.scss']
})
export class GoodsTypeComponent implements OnInit {

    WEB_SERVE_URL = environment.baseUrl;
    imageUrl = environment.imageUrl;
    searchForm: FormGroup; // 搜索框
    requestData = []; // 列表数据
    total: number; // 页码
    pageNum = 1; // 页码
    pageSize = 10; // 条码
    loading = true;
    isVisible = false;
    editFlag = false;
    id: number;
    validateForm!: FormGroup;
    imgFile = [];
    previewImage: string | undefined = '';
    previewVisible = false;
    businessTypeS;
    goodsTypeData;
    goodsTypeDataChild;
    parentIdIsShow = false;
    listModal = false;
    listModalLoading = false;
    editTitle = '编辑';
    parentId;
    constructor(
        private form: FormBuilder,
        private config: ConfigService,
        private iconService: IconService,
        private message: NzMessageService,
        private router: Router,
        private modalService: NzModalService,
        private commonsService: CommonsService,
        private fb: FormBuilder,
    ) {
    }

    ngOnInit(): void {
        this.init();
    }

    public init(): void {
        this.searchForm = this.form.group({
            title: [null],
            businessType: [null],
            parentId: [null],
        });
        this.validateForm = this.fb.group({
            title: [null, [Validators.required]],
            businessType: [null , [Validators.required]],
            parentId: [null],
        });
        this.getRequest(true, this.searchForm.value);

        this.getListGoodsTypeByParentId();
        this.commonsService.getDictionary('BUSINESS_TYPE', data => {
            this.businessTypeS = data['return_data'];
        });
    }

    // 图片查看
    handlePreview = async (file: NzUploadFile) => {
        if (!file.url && !file.preview) {
            // tslint:disable-next-line:no-non-null-assertion
            file.preview = await getBase64(file.originFileObj!);
        }
        this.previewImage = file.url || file.preview;
        this.previewVisible = true;
    }

    public getListGoodsTypeByParentId(parentId?: number): void {
        this.config.getListGoodsTypeByParentId(parentId , data => {
            if (data['return_code'] === '000000') {
                parentId == null ? this.goodsTypeData = data['return_data'] : this.goodsTypeDataChild = data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 查询列表
    public getRequest(reset: boolean = false, whereObject: object) {

        this.loading = false;
        if (reset) {
            this.pageNum = 1;
        }
        whereObject['pageNum'] = this.pageNum;
        whereObject['pageSize'] = this.pageSize;
        this.config.getListGoodsType(whereObject, data => {
            if (data['return_code'] === '000000') {
                this.requestData = data['return_data'].list;
                this.total = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 重置
    public resetForm(): void {
        this.searchForm.reset();
    }


    // 修改
    public getEdit(id?: number , parentId?: number , title?: string): void {
        this.id = id;
        this.parentId = parentId;
        if (title != null) {
            this.editTitle = title + '添加子类';
        }

        if (id != null && parentId == null) {
            this.editFlag = true;
            this.config.getGoodsTypeById(id, data => {
                if (!this.commonsService.whetherStringIsNull(data['return_data']['img'])) {
                    this.imgFile = this.commonsService.stitchImg(data['return_data']['img']);
                }
                data['return_data']['businessType'] = String(data['return_data']['businessType']);
                this.validateForm.patchValue(data['return_data']);
            });
        } else {
            this.validateForm.reset();
            this.editFlag = false;
            this.imgFile = [];
        }
        this.isVisible = true;
    }

    // 查看详情
    public getDetail(id: number): void {
        this.router.navigate(['/admin/company/company-detail'], {
            queryParams: {
                companyId: id
            }
        }).then(r => console.log(r));
    }

    handleOk(): void {
        for (const i in this.validateForm.controls) {
            this.validateForm.controls[i].markAsDirty();
            this.validateForm.controls[i].updateValueAndValidity();
            if (this.validateForm.controls[i].errors != null) {
                return;
            }
        }

        if (this.imgFile.length !== 0) {
            if (this.imgFile[0]['response'] != null) {
                this.validateForm.value.img = this.imgFile[0]['response']['return_data'][0];
            } else {
                this.validateForm.value.img = this.imgFile[0].name;
            }
        }

        if (this.validateForm.value['parentId'] == null) {
            this.validateForm.value['parentId'] = this.parentId;
        }

        if (this.editFlag) {
            this.validateForm.value.id = this.id;

            this.config.updateGoodsType(this.validateForm.value, data => {
                if (data['return_code'] === '000000') {
                    this.message.success('修改成功');
                    this.isVisible = false;
                    this.getRequest(true, this.searchForm.value);
                    this.getListGoodsTypeByParentId(this.validateForm.value['parentId']);
                } else {
                    this.message.create('error', data['return_msg']);
                }
            });
        } else {
            this.config.insertGoodsType(this.validateForm.value, data => {
                if (data['return_code'] === '000000') {
                    this.message.success('添加成功');
                    this.isVisible = false;
                    this.getRequest(true, this.searchForm.value);
                    this.getListGoodsTypeByParentId(this.validateForm.value['parentId']);
                } else {
                    this.message.create('error', data['return_msg']);
                }
            });
        }


    }

    handleCancel(): void {
        this.isVisible = false;
    }

    // 查看子类列表
    public getGoodsTypesChild(parentId: number) {
        this.listModal = true;
        this.getListGoodsTypeByParentId(parentId);
    }

    // 對話框删除
    showDeleteConfirm(id): void {
        this.modalService.confirm({
            nzTitle: '确定删除',
            nzOkText: '是',
            nzOnOk: () => {
                this.config.getGoodsTypeByDelete({
                    id: id
                }, data => {
                    if (data['return_code'] === '000000') {
                        this.message.create('success', `删除成功！`);
                        this.getRequest(true, this.searchForm.value);
                        this.getListGoodsTypeByParentId(this.parentId);
                    } else {
                        this.message.create('error', data['return_msg']);
                    }
                });
            },
            nzCancelText: '否',
        });
    }

}

