import {Component, OnInit, TemplateRef} from '@angular/core';
import {environment} from '../../../../environments/environment';
import {CompanyService} from '../../../services/company.service';
import {LocalStorageService} from '../../../services/local-storage.service';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {CommonsService} from '../../../services/commons.service';
import {OrderMobileRechargeService} from '../../../services/order/order-mobile-recharge.service';
import {FormBuilder, FormGroup} from '@angular/forms';
import {NzMessageService, NzNotificationService} from 'ng-zorro-antd';

import {animate, state, style, transition, trigger} from '@angular/animations';

@Component({
  selector: 'app-mobile-recharge-order-list',
  animations: [
        trigger('openClose', [
            state('open', style({
                height: '260px',
                opacity: 1,
                backgroundColor: 'white'
            })),
            state('closed', style({
                opacity: 1,
                backgroundColor: 'white'
            })),
            transition('open => closed', [
                animate('0.3s')
            ]),
            transition('closed => open', [
                animate('0.3s')
            ]),
        ]),
    ],
  templateUrl: './mobile-recharge-order-list.component.html',
  styleUrls: ['./mobile-recharge-order-list.component.scss']
})
export class MobileRechargeOrderListComponent implements OnInit {

    // 搜索框
    searchForm: FormGroup;
    // 搜索框折叠
    isCollapse = false;
    // 订单状态数据
    orderStatusArray = [];
    // 公司数据
    companyArray = [];
    // 角色类型
    roleType: number;
    // 列表相关参数
    // 总条数
    total: number;
    // 页码
    pageNum = 1;
    // 条码
    pageSize = 10;
    // 列表数据
    requestData = [];
    // 列表加载
    loading = true;
    // 订单详情相关参数
    // 详情模态框
    orderDetailModal = false;
    // 详情模态框数据等待
    orderDetailModalLoading = false;
    isVisible = false;
    // 订单详情数据
    orderDetailObject: any = {
        tradeOrder: {},
        mobileOrder: {},
    };
    // 数据加载中参数
    loadingObject = {
        title: '加载中...',
        status: false,
    };
    // 请求地址参数
    FILE_URL = environment.imageUrl;
    percent = 0;
    processRateInterval;
    constructor(
        private form: FormBuilder,
        private store: LocalStorageService,
        private message: NzMessageService,
        private orderMobileRechargeService: OrderMobileRechargeService,
        private companyService: CompanyService,
        private commonsService: CommonsService,
        private notification: NzNotificationService,
    ) { }

    ngOnInit(): void {
        // 搜索表单初始化
        this.searchForm = this.form.group({
            orderNo: [null],
            memPhone: [null],
            payTimeArray: [null],
            orderStatus: [null],
            createTimeArray: [null],
            refundTimeArray: [null],
            title: [null],
            exceptionStatus: [null],
            companyId: [null],
            payType: [null],
            memCardNo: [null],
            productType: [2],
        });
        // 角色类型初始化
        this.roleType = Number(this.store.get(ADMIN_INFO_OBJECT)['secRole'].roleType);
        // 查询公司列表
        if (this.roleType === 0 || this.roleType === 1) {
            this.companyService.selectCompanyList({ pageNum: 1, pageSize: 999 }, data => {
                this.companyArray = data['return_data']['list'];
            });
        }
        // 查询订单状态数据
        this.commonsService.getDictionary('ORDER_STATUS', data => {
            this.orderStatusArray = data['return_data'];
        });
        this.getRequest(true, this.searchForm.value);
    }

    // 查询列表
    public getRequest(reset: boolean = false, whereObject: object) {
        this.loading = true;
        if (reset) {
            this.pageNum = 1;
        }
        whereObject['pageNum'] = this.pageNum;
        whereObject['pageSize'] = this.pageSize;
        if (whereObject['payTimeArray'] != null && whereObject['payTimeArray'].length !== 0) {
            whereObject['payTimeS'] = whereObject['payTimeArray'][0].getTime();
            whereObject['payTimeE'] = whereObject['payTimeArray'][1].getTime();
        }
        if (whereObject['refundTimeArray'] != null && whereObject['refundTimeArray'].length !== 0) {
            whereObject['refundTimeS'] = whereObject['refundTimeArray'][0].getTime();
            whereObject['refundTimeE'] = whereObject['refundTimeArray'][1].getTime();
        }

        if (whereObject['createTimeArray'] != null && whereObject['createTimeArray'].length !== 0) {
            whereObject['createTimeS'] = whereObject['createTimeArray'][0].getTime();
            whereObject['createTimeE'] = whereObject['createTimeArray'][1].getTime();
        }
        this.orderMobileRechargeService.getOrderList(whereObject, data => {
            this.loading = false;
            if (data['return_code'] === '000000') {
                this.requestData = data['return_data'].list;
                this.total = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 展示订单详情
    public showOrderDetail(orderNo: string) {
        this.orderDetailModal = true;

        this.orderMobileRechargeService.getOrderDetail(orderNo, data => {
            if (data['return_code'] === '000000') {
                this.orderDetailModalLoading = true;
                this.orderDetailObject = data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
            this.orderDetailModalLoading = false;
        });

    }

    // 导出数据
    public excelOrder(whereObject) {

        this.percent = 0;
        whereObject['serialNumber'] = new Date().getTime();
        this.processRate(whereObject['serialNumber']);
        this.isVisible = true;

        this.orderMobileRechargeService.exportMobilePartyOrderList(whereObject, data => {
            if (data['return_code'] !== '000000') {
                this.isVisible = false;
                this.message.error(data['return_msg']);
            }
            this.loadingObject.status = false;
        });
    }


    public refundOrder(orderNo: string): void {

        this.commonsService.showConfirm('请确定当前订单无充值中记录！！！', item => {
            if (item) {
                this.loadingObject.status = true;
                this.loadingObject.title = '订单退款中...';
                this.orderMobileRechargeService.refundOrder(orderNo , data => {
                    if (data['return_code'] === '000000') {
                        this.getRequest(false, this.searchForm.value);
                        this.notification.success('成功' , '退款成功');
                    } else {
                        this.message.error(data['return_msg']);
                        this.notification.error( '失败' , data['return_msg']);
                    }
                    this.loadingObject.status = false;
                });
            }
        });
    }

    public orderNormal(orderNo: string): void {

        if (this.orderDetailModal) {
            this.orderDetailModal = false;
        }

        this.loadingObject.status = true;
        this.loadingObject.title = '修改中...';
        this.orderMobileRechargeService.orderNormal(orderNo , data => {
            if (data['return_code'] === '000000') {
                this.getRequest(false, this.searchForm.value);
                this.notification.success('成功' , '修改成功');
            } else {
                this.message.error(data['return_msg']);
                this.notification.error( '失败' , data['return_msg']);
            }
            this.loadingObject.status = false;
        });
    }


    // 获取导出百分比
    processRate(key: string) {
        this.processRateInterval = setInterval(() => this.commonsService.getRedisValueByType(key, data => {
                this.percent = data['return_data'];
                if (this.percent === 100) {
                    clearTimeout(this.processRateInterval);
                    this.loadingObject.status = true;
                    this.loadingObject.title = '下载中...';
                    const interval = setInterval(() => this.commonsService.getRedisValueByType(key + 'download', download => {
                        if (download['return_data'] != null) {
                            this.message.success('下载成功！');
                            this.loadingObject.status = false;
                            window.location.href = this.FILE_URL + 'temporary/' + download['return_data'];
                            this.isVisible = false;
                            clearTimeout(interval);
                        }
                    }), 100);
                }
        }), 300);


    }

}

