import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {CouponService} from '../../../services/coupon.service';
import {DiscountService} from '../../../services/discount.service';
import {NzModalService} from 'ng-zorro-antd';

@Component({
  selector: 'app-coupon-use',
  templateUrl: './coupon-use.component.html',
  styleUrls: ['./coupon-use.component.scss']
})
export class CouponUseComponent implements OnInit {
  tableLoading = true;
  countObject: any = {
    batchNum: 0,
    useNum: 0,
    usePrice: 0,
    useRate: 0,
  };
  dataObject: any = {};
  usingRangeArray = [
    { codeValue: 10, codeName: '贵州中石化'},
    { codeValue: 8, codeName: '重庆中石油'},
  ]
  salesPriceArray = [];
  searchForm: FormGroup;
  whereObject: any = {};
  pageNum = 1;
  pageSize = 10;

  modifyModal = false;
  batchObject = {};
  modifyForm: FormGroup;
  constructor(private form: FormBuilder,
              private modal: NzModalService,
              private  couponService: CouponService,
              private  discountService: DiscountService,
  ) { }

  ngOnInit(): void {
    this.searchForm = this.form.group({
      usingRange: [String(this.usingRangeArray[0].codeValue)],
      price: ['null'],
    });
    this.modifyForm = this.form.group({
      batchIdentifier: [null, [Validators.required]],
      mailTime: [null],
      batchNum: [null],
    });
  }


  getData() {
    this.tableLoading = true;
    const param = this.searchForm.value;
    if (this.searchForm.controls['price'].value == 'null') {
      param['price'] = null;
    }
    param['pageNum'] = this.pageNum;
    param['pageSize'] = this.pageSize;
    this.couponService.getCount(param,response => {
      const returnData = response['return_data'];
      if (returnData != null) {
        this.countObject = returnData;
      } else {
        this.countObject.batchNum = 0;
        this.countObject.useNum = 0;
        this.countObject.usePrice = 0;
        this.countObject.useRate = 0;
      }
    });
    this.couponService.getBatchUseCount(param, response => {
       this.dataObject = response['return_data'];
       this.tableLoading = false;
    });
  }

  /**
   * 查询卡券销售面值
   */
  getCouponSalesPrice() {
    this.salesPriceArray = [];
    this.discountService.getDiscountPrice(this.searchForm.controls['usingRange'].value, data => {
        for (let obj of data['return_data']) {
          this.salesPriceArray.push({ codeValue: obj, codeName: obj});
        }
        this.searchForm.controls['price'].setValue('null');
        this.getData();
    });
  }

  pageIndexChange(pageNum: number) {
    this.pageNum = pageNum;
    this.getData();
  }


  openModifyModal(batchIdentifier: string) {
    this.discountService.getBatchDetail(batchIdentifier, data => {
       this.batchObject = data['return_data'];
       this.modifyForm.controls['batchIdentifier'].setValue(this.batchObject['batchIdentifier']);
    });
    this.modifyModal = true;
  }

  submitModify() {
    this.discountService.replenish(this.modifyForm.value, data => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '提交成功',
        });
        this.getData();
        this.closeModifyModal();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });
  }

  closeModifyModal() {
    this.modifyForm.reset();
    this.modifyModal = false;
  }

}
