import {Component, OnInit} from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {UserService} from '../../../services/user.service';
import {NzMessageService} from 'ng-zorro-antd';
import {IconService} from '../../../services/icon.service';
import {CommonsService} from '../../../services/commons.service';
import {environment} from '../../../../environments/environment';
import {OrderService} from '../../../services/order.service';

@Component({
    selector: 'app-user-list',
    templateUrl: './user-list.component.html',
    styleUrls: ['./user-list.component.scss']
})
export class UserListComponent implements OnInit {
    WEB_SERVE_URL = environment.baseUrl;
    searchForm: FormGroup; // 搜索框
    requestData = []; // 列表数据
    total: number; // 页码
    pageNum = 1; // 页码
    pageSize = 10; // 条码
    loading = true;
    regTime;
    orderListModal = false;
    isVisible = false;
    orderListModalLoading = false;
    requestOrderData = [];

    percent = 0;
    processRateInterval;
    FILE_URL = environment.imageUrl;

    userId;
    loadingObject = {
        title: '加载中...',
        status: false,
    };
    serialNumber;
    constructor(
        private form: FormBuilder,
        private user: UserService,
        private iconService: IconService,
        private orderService: OrderService,
        private message: NzMessageService,
        private common: CommonsService
    ) {
    }

    ngOnInit(): void {
        this.init();
    }

    public init(): void {
        this.searchForm = this.form.group({
            name: [null],
            status: [null],
            isAgent: [null],
            phone: [null],
            regTime: [null],
        });
        this.getRequest(true, this.searchForm.value);
    }

    // 查询列表
    public getRequest(reset: boolean = false, whereObject: object) {

        if (whereObject['regTime'] != null && whereObject['regTime'].length !== 0) {
            whereObject['regTimeStart'] = whereObject['regTime'][0].getTime();
            whereObject['regTimeEnd'] = whereObject['regTime'][1].getTime();
        }

        this.loading = false;
        if (reset) {
            this.pageNum = 1;
        }
        whereObject['pageNum'] = this.pageNum;
        whereObject['pageSize'] = this.pageSize;
        this.user.getListUser(whereObject, data => {
            if (data['return_code'] === '000000') {
                this.requestData = data['return_data'].list;
                this.total = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 重置
    public resetForm(): void {
        this.searchForm.reset();
    }

    public getForbiddenUser(id, status: any): void {
        const message = (status === 1 ? '是否禁用当前用户' : '是否启用当前用户');

        this.common.showConfirm(message, data => {
            if (data) {
                this.user.forbiddenUser(id, dataUser => {
                    this.getRequest(false , this.searchForm.value);
                });
            }
        });
    }

    // 是否设置成代理商
    setUpAgent(id , isAgent: boolean) {
        const message = (isAgent === true ? '当前用户禁用推广员' : '启用推广员');

        this.common.showConfirm(message, data => {
            if (data) {
                this.user.setUpAgent(id, dataUser => {
                    if (dataUser['return_code'] === '000000') {
                        this.message.success('操作成功');
                        this.getRequest(false , this.searchForm.value);
                    } else {
                        this.message.error(dataUser['return_msg']);
                    }

                });
            }
        });
    }

    public getList(userId: string): void {
        this.orderListModalLoading = true;
        this.orderListModal = true;
        this.userId = userId;
        this.orderService.getPopularizeUserOrderList(userId , data => {
            this.orderListModalLoading  = false;
            if (data['return_code'] === '000000') {
                this.requestOrderData = data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    public excelOrder() {
        const whereObject = {};
        this.percent = 0;
        this.serialNumber = new Date().getTime();
        whereObject['serialNumber'] = this.serialNumber;
        whereObject['promoteCode'] = this.userId;
        this.isVisible = true;
        this.processRate(this.serialNumber);
        this.orderService.exportPopularizeUserOrderList(whereObject, data => {
            if (data['return_code'] !== '000000') {
                this.isVisible = false;
                this.message.error(data['return_msg']);
            }
            this.loadingObject.status = false;
        });
    }


    // 获取导出百分比
    processRate(key: string) {
        this.processRateInterval = setInterval(() => this.common.getRedisValueByType(key, data => {
            this.percent = data['return_data'];
            if (this.percent === 100) {
                clearTimeout(this.processRateInterval);
                this.loadingObject.status = true;
                this.loadingObject.title = '下载中...';
                const interval = setInterval(() => this.common.getRedisValueByType(key + 'download', download => {
                    if (download['return_data'] != null) {
                        this.message.success('下载成功！');
                        this.loadingObject.status = false;
                        window.location.href = this.FILE_URL + 'temporary/' + download['return_data'];
                        this.isVisible = false;
                        clearTimeout(interval);
                    }
                }), 100);
            }
        }), 300);


    }

}
