import { Injectable } from '@angular/core';
import {CommonsService} from '../commons.service';
import {environment} from '../../../environments/environment';
import {HttpClient} from '@angular/common/http';

@Injectable({
  providedIn: 'root'
})
export class GoodsService {

  constructor(
      private http: HttpClient,
      private common: CommonsService
  ) { }


    /**
     * 查询列表
     *
     * @param  paramsObject   对象
     * @param  callBack   回调
     */
    public getListGoodsDetail(paramsObject: object, callBack) {
        this.http.get(environment.baseUrl + 'goods/getListGoodsDetail?' + this.common.getWhereCondition(paramsObject)).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName insertProduct
     * @Description // 新增商品
     * @Date 13:54 2023/4/12
     * @Param params 上传对象
     * @Param callBack 回调
     */
    public insertGoods(params: object, callBack) {
        this.http.post(environment.baseUrl + 'goods/insertGoods', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName editPriceStatus
     * @Description // 修改商品
     * @Date 15:03 2021/8/12
     * @Param mod
     **/
    public updateGoods(params: object, callBack) {
        this.http.post(environment.baseUrl + 'goods/updateGoods', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName findGoodsDetailById
     * @Description // 查询商品详情
     * @Date 13:58 2023/4/12
     * @Param id 商户编码
     * @Param callBack
     */
    public findGoodsDetailById(id: number, callBack) {
        this.http.get(environment.baseUrl + 'goods/findGoodsDetailById?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName getGoodsTypeTree
     * @Description // 查询商品类型树
     * @Date 18:33 2023/4/12
     * @Param businessType 业务类型
     * @Param callBack 回调
     */
    public getGoodsTypeTree(businessType: number, callBack) {
        this.http.get(environment.baseUrl + 'highGoodsType/getGoodsTypeTree?businessType=' + businessType).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName getListGoodsSku
     * @Description // 查询商品SKU
     * @Date 18:34 2023/4/12
     * @Param paramsObject
     * @Param callBack
     */
    public getListGoodsSku(paramsObject: object, callBack) {
        this.http.get(environment.baseUrl + 'goodsSku/getListGoodsSku?' + this.common.getWhereCondition(paramsObject)).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName insertGoodsSku
     * @Description // 新增商品SKU
     * @Date 18:35 2023/4/12
     * @Param params
     * @Param callBack
     */
    public insertGoodsSku(params: object, callBack) {
        this.http.post(environment.baseUrl + 'goodsSku/insertGoodsSku', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName updateGoodsSku
     * @Description // 更新商品SKU
     * @Date 18:35 2023/4/12
     * @Param params
     * @Param callBack
     */
    public updateGoodsSku(params: object, callBack) {
        this.http.post(environment.baseUrl + 'goodsSku/updateGoodsSku', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName findGoodsSkuById
     * @Description // 查询商品SKU详情
     * @Date 18:36 2023/4/12
     * @Param id
     * @Param callBack
     */
    public findGoodsSkuById(id: number, callBack) {
        this.http.get(environment.baseUrl + 'goodsSku/findGoodsSkuById?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName deleteSku
     * @Description // 删除sku
     * @Date 11:38 2023/4/13
     * @Param id
     */
    public deleteSku(id: number, callBack) {
        this.http.get(environment.baseUrl + 'goodsSku/deleteSku?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName goodsUpDown
     * @Description // 商品上下架
     * @Date 11:38 2023/4/13
     * @Param id
     */
    public goodsUpDown(id: number, callBack) {
        this.http.get(environment.baseUrl + 'goods/goodsUpDown?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName deleteGoods
     * @Description // 删除商品
     * @Date 11:39 2023/4/13
     * @Param id
     */
    public deleteGoods(id: number, callBack) {
        this.http.get(environment.baseUrl + 'goods/deleteGoods?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName getListRegionFreight
     * @Description // 查询区域运费内容
     * @Date 16:50 2023/4/14
     * @Param paramsObject
     */
    public getListRegionFreight(paramsObject: object, callBack) {
        this.http.get(environment.baseUrl + 'regionFreight/getListRegionFreight?' + this.common.getWhereCondition(paramsObject)).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName insertRegionFreight
     * @Description // 插入区域运费
     * @Date 16:51 2023/4/14
     * @Param params
     */
    public insertRegionFreight(params: object, callBack) {
        this.http.post(environment.baseUrl + 'regionFreight/insertRegionFreight', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName updateRegionFreight
     * @Description // 查询区域内容
     * @Date 16:51 2023/4/14
     * @Param params
     */
    public updateRegionFreight(params: object, callBack) {
        this.http.post(environment.baseUrl + 'regionFreight/updateRegionFreight', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName deleteRegionFreight
     * @Description // 删除区域运费内容
     * @Date 16:52 2023/4/14
     * @Param id
     */
    public deleteRegionFreight(id: number, callBack) {
        this.http.get(environment.baseUrl + 'regionFreight/deleteRegionFreight?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName findRegionFreightById
     * @Description // 查询区域运费内容
     * @Date 16:53 2023/4/14
     * @Param id
     */
    public findRegionFreightById(id: number, callBack) {
        this.http.get(environment.baseUrl + 'regionFreight/findRegionFreightById?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName insertPresent
     * @Description // 新增赠送内容
     * @Date 15:07 2023/4/18
     * @Param params
     */
    public insertPresent(params: object, callBack) {
        this.http.post(environment.baseUrl + 'goodsPresent/insertPresent', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName updatePresent
     * @Description // 更新赠送内容
     * @Date 15:07 2023/4/18
     * @Param params
     */
    public updatePresent(params: object, callBack) {
        this.http.post(environment.baseUrl + 'goodsPresent/updatePresent', params).subscribe(data => {
            callBack(data);
        });
    }


    /**
     * @Author Sum1Dream
     * @methodName getListPresent
     * @Description // 查询赠送配置列表
     * @Date 15:08 2023/4/18
     * @Param paramsObject
     */
    public getListPresent(paramsObject: object, callBack) {
        this.http.get(environment.baseUrl + 'goodsPresent/getListPresent?' + this.common.getWhereCondition(paramsObject)).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName deleteGoods
     * @Description // 删除
     * @Date 15:09 2023/4/18
     * @Param id
     */
    public deletePresent(id: number, callBack) {
        this.http.get(environment.baseUrl + 'goodsPresent/deletePresent?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    public getOrderList(param: object, callBack) {
        this.http.get(environment.orderUrl + 'goodsOrder/getOrderList?' + this.common.getWhereCondition(param)).subscribe(data => {
            callBack(data);
        });
    }


    public getOrderChildList(param: object, callBack) {
        this.http.get(environment.orderUrl + 'goodsOrder/getOrderChildList?' + this.common.getWhereCondition(param)).subscribe(data => {
            callBack(data);
        });
    }

    public updateLogisticsNo(param: object, callBack) {
        this.http.get(environment.orderUrl + 'goodsOrder/updateLogisticsNo?' + this.common.getWhereCondition(param)).subscribe(data => {
            callBack(data);
        });
    }

    public editLogisticsNo(param: object, callBack) {
        this.http.get(environment.orderUrl + 'goodsOrder/editLogisticsNo?' + this.common.getWhereCondition(param)).subscribe(data => {
            callBack(data);
        });
    }

    public getGoodsOrderDetail(orderNo: string, callBack) {
        this.http.get(environment.orderUrl + 'goodsOrder/getGoodsOrderDetail?orderNo=' + orderNo).subscribe(data => {
            callBack(data);
        });
    }

    public getLogisticsMsg(orderId: number , callBack) {
        this.http.get(environment.baseUrl + 'goods/getLogisticsMsg?orderId=' + orderId).subscribe(data => {
            callBack(data);
        });
    }



}
